#[non_exhaustive]pub struct ClliBox {
pub max_content_light_level: u16,
pub max_pic_average_light_level: u16,
}Expand description
Content Light Level Information box (clli), per ISOBMFF  12.1.5 / CEA-861.3.
Signals the content light level of HDR content to the display. Both values are in cd/m² (nits).
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.max_content_light_level: u16Maximum light level of any single pixel in the content (MaxCLL).
max_pic_average_light_level: u16Maximum average light level of any single frame in the content (MaxFALL).
Implementations